@@ -146,11 +146,13 @@ fn trim_utf8_bom(s: &str) -> &str {
     }
 }
 
+mod array;
+use array::parse_array;
+
 mod access;
 mod addressblock;
 mod bitrange;
 mod cluster;
-mod clusterinfo;
 mod cpu;
 mod device;
 mod dimelement;
@@ -158,16 +160,13 @@ mod endian;
 mod enumeratedvalue;
 mod enumeratedvalues;
 mod field;
-mod fieldinfo;
 mod interrupt;
 mod modifiedwritevalues;
 mod peripheral;
-mod peripheralinfo;
 mod protection;
 mod readaction;
 mod register;
 mod registercluster;
-mod registerinfo;
 mod registerproperties;
 mod usage;
 mod writeconstraint;
